==============
Tacker Horizon
==============

Horizon UI for NFV Orchestration (Tacker)

* License: `Apache license <http://www.apache.org/licenses/LICENSE-2.0>`_
* Tacker-horizon docs: https://docs.openstack.org/tacker-horizon/latest
* Source: https://opendev.org/openstack/tacker-horizon
* Bugs: https://bugs.launchpad.net/tacker

Contents
--------

.. toctree::
   :maxdepth: 2

   install/index
   configuration/index
   user/index
   contributor/index


Indices and tables
------------------

* :ref:`search`
